@@ -53,6 +53,7 @@ class RaeMote(hildondesktop.HomePluginItem):
         self.set_colormap(colormap)
 
         self.overlay = None
+        self._clear_overlay_source_id = None
         self.set_size_request(self.image.get_width(),
                               self.image.get_height())
 
@@ -82,7 +83,7 @@ class RaeMote(hildondesktop.HomePluginItem):
         dialog.add_button('Visit website', 1)
         dialog.add_button('Report bug', 2)
         dialog.add_button('Donate', 3)
-        dialog.vbox.add(gtk.Label('Version 1.1 (2010-03-18)'))
+        dialog.vbox.add(gtk.Label('Version 1.2 (2010-03-20)'))
         dialog.vbox.add(gtk.Label('Copyright (c) 2010 Thomas Perl <http://thpinfo.com>'))
         dialog.show_all()
         result = dialog.run()
@@ -107,11 +108,20 @@ class RaeMote(hildondesktop.HomePluginItem):
                     self.overlay = self.load_overlay(rectangle.action)
                     self.queue_draw()
                     send_ir(self.remote_name, rectangle.action)
+
+                    # Remove the overlay after 100ms
+                    self._clear_overlay_source_id = \
+                            gobject.timeout_add(100, self.on_button_release)
                     return
 
-    def on_button_release(self, widget, event):
-        self.overlay = None
-        self.queue_draw()
+    def on_button_release(self, widget=None, event=None):
+        if self._clear_overlay_source_id is not None:
+            gobject.source_remove(self._clear_overlay_source_id)
+            self.overlay = None
+            self.queue_draw()
+            self._clear_overlay_source_id = None
+
+        return False
 
     def on_expose_event(self, widget, event):
         cr = widget.window.cairo_create()
